package com.yonge.cooleshow.student.controller;


import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.dto.ActivityEvaluationRecordDto;
import com.yonge.cooleshow.biz.dal.dto.EvaluationRecordDto;
import com.yonge.cooleshow.biz.dal.entity.SysMusicCompareRecord;
import com.yonge.cooleshow.biz.dal.service.ActivityEvaluationRecordService;
import com.yonge.cooleshow.biz.dal.service.ActivityPlanService;
import com.yonge.cooleshow.biz.dal.vo.MusicActivityVo;
import com.yonge.cooleshow.common.controller.BaseController;
import com.yonge.cooleshow.common.entity.HttpResponseResult;
import com.yonge.toolset.base.exception.BizException;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.Objects;


@Api(tags = "学生活动接口")
@RestController
@RequestMapping("/activity")
public class StudentActivityController extends BaseController {
    private final static Logger log = LoggerFactory.getLogger(StudentActivityController.class);
    @Autowired
    private SysUserFeignService sysUserFeignService;

    @Autowired
    private ActivityPlanService activityPlanService;

    @Autowired
    private ActivityEvaluationRecordService activityEvaluationRecordService;

    @ApiOperation(value = "评测活动参与项目", notes = "评测项目id")
    @PostMapping(value = "/evaluation/{evaluationId}")
    public HttpResponseResult<Boolean> joinEvaluation(@PathVariable Long evaluationId) {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null || null == user.getId()) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }

        return succeed(activityPlanService.joinEvaluation(evaluationId, user));
    }


    @ApiOperation(value = "免费活动报名活动报名", notes = "活动id")
    @PostMapping(value = "/joinActivity/{id}")
    public HttpResponseResult<Boolean> joinActivity(@PathVariable Long id) {
        SysUser user = sysUserFeignService.queryUserInfo();
        if (user == null || null == user.getId()) {
            return failed(HttpStatus.FORBIDDEN, "请登录");
        }

        return succeed(activityPlanService.joinActivity(id, user));
    }


    @ApiOperation(value = "保存活动分数")
    @PostMapping("/evaluationScore")
    public HttpResponseResult evaluationScore( @RequestBody EvaluationRecordDto record){

        // 判断是否为活动评测 活动评测 记录活动记录
        if (record.getEvaluationId() != null) {
            try {
                activityEvaluationRecordService.saveRecord(record.getEvaluationId(),record.getUserId(),record.getScore());
            } catch (Exception e) {
                e.printStackTrace();
                log.error("活动评测记录保存失败，{}",e.fillInStackTrace());
            }
        }
        return succeed();
    }
}

